@@ -1,4 +1,4 @@
-from .base import MetricsLayerBase
+from .base import AccessDeniedOrDoesNotExistException, MetricsLayerBase
 from .join import Join
 from .set import Set
 
@@ -39,13 +39,15 @@ class Explore(MetricsLayerBase):
 
     def validate_fields(self):
         errors = []
+        if not self.valid_name(self.name):
+            errors.append(self.name_error("explore", self.name))
 
         for join in self.joins():
             errors.extend(join.collect_errors())
 
         for view_name in self.view_names():
             try:
-                view = self.project.get_view(view_name)
+                view = self.project.get_view(view_name, explore=self)
             except Exception:
                 errors.append(f"View {view_name} cannot be found in explore {self.name}")
                 continue
@@ -56,7 +58,6 @@ class Explore(MetricsLayerBase):
 
             referenced_fields = view.referenced_fields()
             view_errors = view.collect_errors()
-
             errors.extend(
                 [
                     f"Could not locate reference {field} in view {view_name} in explore {self.name}"
@@ -105,3 +106,18 @@ class Explore(MetricsLayerBase):
             if join.is_valid():
                 output.append(join)
         return output
+
+    def explore_fields(self, show_hidden: bool, expand_dimension_groups: bool, show_excluded: bool):
+        try:
+            view = self.project.get_view(self.from_, explore=self)
+            fields = view.fields(show_hidden, expand_dimension_groups)
+        except AccessDeniedOrDoesNotExistException:
+            fields = []
+
+        for join in self.joins():
+            fields.extend(join.join_fields(show_hidden, expand_dimension_groups, show_excluded))
+
+        explore_field_names = self.field_names()
+        if explore_field_names and not show_excluded:
+            return [f for f in fields if f.id(view_only=True) in explore_field_names]
+        return fields
