@@ -1,6 +1,7 @@
 import functools
 import hashlib
 import json
+from collections import Counter
 
 from .base import AccessDeniedOrDoesNotExistException
 from .dashboard import Dashboard
@@ -52,6 +53,9 @@ class Project:
 
     def validate(self):
         all_errors = []
+        for model in self.models():
+            all_errors.extend(model.collect_errors())
+
         for explore in self.explores():
             errors = explore.validate_fields()
             all_errors.extend(errors)
@@ -59,7 +63,23 @@ class Project:
         for dashboard in self.dashboards():
             errors = dashboard.collect_errors()
             all_errors.extend(errors)
-        return all_errors
+
+        all_errors.extend(self._validate_dashboard_names())
+
+        return list(sorted(set(all_errors), key=lambda x: all_errors.index(x)))
+
+    def _validate_dashboard_names(self):
+        # We need to make sure the unique identifiers for the dashboards are actually unique
+        errors = []
+        dashboard_names = [d.name for d in self.dashboards()]
+        name_frequency = Counter(dashboard_names).most_common()
+        for name, frequency in name_frequency:
+            if frequency > 1:
+                msg = f"Dashboard name {name} appears {frequency} times, make sure dashboard names are unique"
+                errors.append(msg)
+            else:
+                break
+        return errors
 
     def _all_dashboards(self):
         dashboards = []
@@ -112,6 +132,10 @@ class Project:
         can_access_view = self.can_access_view(field.view)
         return self._can_access_object(field) and can_access_view
 
+    def can_access_merged_field(self, field, explore: Explore):
+        can_access_explore = self.can_access_explore(explore)
+        return self._can_access_object(field) and can_access_explore
+
     def _can_access_object(self, obj):
         if self._user is not None:
             if obj.required_access_grants:
@@ -220,13 +244,10 @@ class Project:
         if explore_name is None and view_name is None:
             return self._all_fields(show_hidden, expand_dimension_groups)
         elif view_name and explore_name:
-            return self._view_fields(
-                view_name, self.get_explore(explore_name), show_hidden, expand_dimension_groups
-            )
+            fields = self._explore_fields(explore_name, show_hidden, expand_dimension_groups, show_excluded)
+            return [f for f in fields if f.view.name == view_name]
         elif view_name:
-            return self._view_fields(
-                view_name, show_hidden=show_hidden, expand_dimension_groups=expand_dimension_groups
-            )
+            return self._view_fields(view_name, show_hidden, expand_dimension_groups)
         else:
             return self._explore_fields(explore_name, show_hidden, expand_dimension_groups, show_excluded)
 
@@ -236,9 +257,9 @@ class Project:
     def _view_fields(
         self,
         view_name: str,
-        explore: Explore = None,
         show_hidden: bool = True,
         expand_dimension_groups: bool = False,
+        explore: Explore = None,
     ):
         view = self.get_view(view_name, explore=explore)
         if not view:
@@ -250,20 +271,15 @@ class Project:
         self, explore_name: str, show_hidden: bool, expand_dimension_groups: bool, show_excluded: bool
     ):
         explore = self.get_explore(explore_name)
-        valid_views = self.views_with_explore(explore=explore)
-        fields = [f for v in valid_views for f in v.fields(show_hidden, expand_dimension_groups)]
-
-        if explore.fields and not show_excluded:
-            field_names = explore.field_names()
-            fields_in_explore = []
-            for field in fields:
-                if any(field.equal(fn) for fn in field_names):
-                    fields_in_explore.append(field)
-            return fields_in_explore
-        return fields
+        if show_excluded:
+            valid_views = self.views_with_explore(explore=explore)
+            return [f for v in valid_views for f in v.fields(show_hidden, expand_dimension_groups)]
+        return explore.explore_fields(show_hidden, expand_dimension_groups, show_excluded)
 
     @functools.lru_cache(maxsize=None)
-    def get_field(self, field_name: str, explore_name: str = None, view_name: str = None) -> Field:
+    def get_field(
+        self, field_name: str, explore_name: str = None, view_name: str = None, show_excluded: bool = False
+    ) -> Field:
         # Handle the case where the explore syntax is passed: explore_name.view_name.field_name
         if "." in field_name:
             specified_explore_name, specified_view_name, field_name = Field.field_name_parts(field_name)
@@ -281,16 +297,20 @@ class Project:
 
         field_name = field_name.lower()
 
-        fields = self.fields(explore_name=explore_name, view_name=view_name, expand_dimension_groups=True)
+        fields = self.fields(
+            explore_name=explore_name,
+            view_name=view_name,
+            expand_dimension_groups=True,
+            show_excluded=show_excluded,
+        )
         matching_fields = [f for f in fields if f.equal(field_name)]
         return self._matching_field_handler(matching_fields, field_name, explore_name, view_name)
 
     def get_explore_from_field(self, field_name: str):
         # If it's specified this is really easy
-        if "." in field_name:
-            explore_name, _, _ = Field.field_name_parts(field_name)
-            if explore_name is not None:
-                return explore_name
+        explore_name, view_name, to_match = Field.field_name_parts(field_name)
+        if explore_name is not None:
+            return explore_name
 
         # If it's not we have to check all explores to make sure the field isn't ambiguously referenced
         all_fields_with_explore_duplicates = []
@@ -298,7 +318,9 @@ class Project:
             for view in self.views_with_explore(explore_name=explore.name):
                 all_fields_with_explore_duplicates.extend(view.fields(expand_dimension_groups=True))
 
-        matching_fields = [f for f in all_fields_with_explore_duplicates if f.name == field_name]
+        matching_fields = [f for f in all_fields_with_explore_duplicates if f.alias() == to_match]
+        if view_name:
+            matching_fields = [f for f in matching_fields if f.view.name == view_name]
         match = self._matching_field_handler(matching_fields, field_name)
         return match.view.explore.name
 
@@ -309,7 +331,17 @@ class Project:
             return matching_fields[0]
 
         elif len(matching_fields) > 1:
-            matching_names = [self._fully_qualified_name(f) for f in matching_fields]
+            # if exerything is in the same view we can pick the explore that uses this view as the from_ view
+            if len(set([f.view.name for f in matching_fields])) == 1:
+                view_name = matching_fields[0].view.name
+                matching_explores = [e for e in self.explores() if e.from_ == view_name]
+                # This method will work iff there is exactly one matchng explore
+                if len(matching_explores) == 1:
+                    for f in matching_fields:
+                        if f.view.explore.name == matching_explores[0].name:
+                            return f
+
+            matching_names = [f.id() for f in matching_fields]
             explore_text = f", in explore {explore_name}" if explore_name else ""
             view_text = f", in view {view_name}" if view_name else ""
             err_msg = (
@@ -344,10 +376,3 @@ class Project:
                 f"project to resolve the dbt ref('{ref_name}') in view {view_name}"
             )
         return self.manifest.resolve_name(ref_name)
-
-    @staticmethod
-    def _fully_qualified_name(field: Field):
-        name = f"{field.view.name}.{field.name}"
-        if field.view.explore:
-            name = f"{field.view.explore.name}.{name}"
-        return name
