@@ -45,11 +45,17 @@ class BaseRepo:
 
 
 class LocalRepo(BaseRepo):
-    def __init__(self, repo_path: str, repo_type: str = None, warehouse_type: str = None) -> None:
+    def __init__(
+        self, repo_path: str, repo_type: str = None, dbt_path: str = None, warehouse_type: str = None
+    ) -> None:
         self.repo_path = repo_path
+        self.dbt_path = dbt_path
+        if isinstance(dbt_path, str) and dbt_path[-1] != "/":
+            self.dbt_path += "/"
         self.repo_type = repo_type
         self.warehouse_type = warehouse_type
         self.folder = f"{os.path.join(os.getcwd(), self.repo_path)}/"
+        self.branch_options = []
 
     def search(self, pattern: str):
         """Example arg: pattern='*.model.*'"""
@@ -70,7 +76,9 @@ class GithubRepo(BaseRepo):
         self.repo_name = utils.generate_uuid()
         self.repo_destination = os.path.join(BASE_PATH, self.repo_name)
         self.folder = f"{self.repo_destination}/"
+        self.dbt_path = self.folder
         self.branch = branch
+        self.branch_options = []
 
     def search(self, pattern: str):
         """Example arg: pattern='*.model.*'"""
@@ -79,6 +87,19 @@ class GithubRepo(BaseRepo):
     def fetch(self):
         self.fetch_github_repo(self.repo_url, self.repo_destination, self.branch)
 
+        try:
+            dynamic_branch_options = []
+            g = git.cmd.Git()
+            raw = g.ls_remote(self.repo_url)
+            for raw_branch_ref in raw.split("\n"):
+                if "/heads/" in raw_branch_ref:
+                    clean_branch_ref = raw_branch_ref.split("/heads/")[-1]
+                    dynamic_branch_options.append(clean_branch_ref)
+            self.branch_options = dynamic_branch_options
+        except Exception as e:
+            print(f"Exception getting branch options: {e}")
+            self.branch_options = [self.branch]
+
     def delete(self, folder: str = None):
         if folder is None:
             folder = self.folder
@@ -90,7 +111,8 @@ class GithubRepo(BaseRepo):
     def fetch_github_repo(repo_url: str, repo_destination: str, branch: str):
         if os.path.exists(repo_destination) and os.path.isdir(repo_destination):
             shutil.rmtree(repo_destination)
-        git.Repo.clone_from(repo_url, to_path=repo_destination, branch=branch, depth=1)
+        repo = git.Repo.clone_from(repo_url, to_path=repo_destination, branch=branch, depth=1)
+        return repo
 
 
 class LookerGithubRepo(BaseRepo):
@@ -104,6 +126,8 @@ class LookerGithubRepo(BaseRepo):
         self.repo_type = repo_type
         self.repo_url, self.branch = self.get_looker_github_info()
         self.repo = GithubRepo(self.repo_url, self.branch)
+        self.dbt_path = self.repo.folder
+        self.branch_options = []
 
     def search(self, pattern: str):
         """Example arg: pattern='*.model.*'"""
@@ -111,6 +135,7 @@ class LookerGithubRepo(BaseRepo):
 
     def fetch(self) -> None:
         self.repo.fetch()
+        self.branch_options = self.repo.branch_options
 
     def delete(self, folder: str = None) -> None:
         self.repo.delete(folder=folder)
