@@ -58,11 +58,23 @@ class MetricsLayerDesign:
         self._join_graph = networkx.DiGraph()
         for join in joins_needed:
             for view_name in join.required_views():
-                self._join_graph.add_edge(view_name, join.from_, relationship=join.relationship)
-        self._ordered_join_names = list(networkx.dfs_tree(self._join_graph, source=self.base_view_name))
+                if view_name != join.from_:
+                    self._join_graph.add_edge(view_name, join.from_, relationship=join.relationship)
+
+        self._ordered_join_names = list(networkx.topological_sort(self._join_graph))
         # Skip the first one because that's *always* the base of the explore
         return [self.explore.get_join(name, by_view_name=True) for name in self._ordered_join_names[1:]]
 
+    @staticmethod
+    def chain_decomposition(graph, root):
+        result = []
+        for decomp in networkx.chain_decomposition(graph, root=root):
+            if decomp[0][0] == root:
+                result = []
+                for edge in decomp:
+                    result.append(edge[0])
+        return result
+
     def functional_pk(self):
         sorted_joins = self.joins()
         if len(sorted_joins) == 0:
